==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIViewControllerContextTransitioningAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIViewControllerContextTransitioningAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements UIViewControllerContextTransitioning/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("containerView")
    public UIView getContainerView() { return null; }
    @NotImplemented("isAnimated")
    public boolean isAnimated() { return false; }
    @NotImplemented("isInteractive")
    public boolean isInteractive() { return false; }
    @NotImplemented("transitionWasCancelled")
    public boolean transitionWasCancelled() { return false; }
    @NotImplemented("presentationStyle")
    public UIModalPresentationStyle getPresentationStyle() { return null; }
    @NotImplemented("updateInteractiveTransition:")
    public void updateInteractiveTransition(@MachineSizedFloat double percentComplete) {}
    @NotImplemented("finishInteractiveTransition")
    public void finishInteractiveTransition() {}
    @NotImplemented("cancelInteractiveTransition")
    public void cancelInteractiveTransition() {}
    @NotImplemented("completeTransition:")
    public void completeTransition(boolean didComplete) {}
    @NotImplemented("viewControllerForKey:")
    public UIViewController getViewController(UITransitionContextViewControllerType key) { return null; }
    /**
     * @since Available in iOS 8.0 and later.
     */
    @NotImplemented("viewForKey:")
    public UIView getView(UITransitionContextViewType key) { return null; }
    /**
     * @since Available in iOS 8.0 and later.
     */
    @NotImplemented("targetTransform")
    public @ByVal CGAffineTransform getTargetTransform() { return null; }
    @NotImplemented("initialFrameForViewController:")
    public @ByVal CGRect getInitialFrame(UIViewController vc) { return null; }
    @NotImplemented("finalFrameForViewController:")
    public @ByVal CGRect getFinalFrame(UIViewController vc) { return null; }
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/UIViewControllerContextTransitioningAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIViewControllerContextTransitioningAdapter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements UIViewControllerContextTransitioning/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    @NotImplemented("containerView")
    public UIView getContainerView() { return null; }
    @NotImplemented("isAnimated")
    public boolean isAnimated() { return false; }
    @NotImplemented("isInteractive")
    public boolean isInteractive() { return false; }
    @NotImplemented("transitionWasCancelled")
    public boolean isTransitionWasCancelled() { return false; }
    @NotImplemented("presentationStyle")
    public UIModalPresentationStyle getPresentationStyle() { return null; }
    @NotImplemented("targetTransform")
    public @ByVal CGAffineTransform getTargetTransform() { return null; }
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("updateInteractiveTransition:")
    public void updateInteractiveTransition(@MachineSizedFloat double percentComplete) {}
    @NotImplemented("finishInteractiveTransition")
    public void finishInteractiveTransition() {}
    @NotImplemented("cancelInteractiveTransition")
    public void cancelInteractiveTransition() {}
    /**
     * @since Available in iOS 10.0 and later.
     */
    @NotImplemented("pauseInteractiveTransition")
    public void pauseInteractiveTransition() {}
    @NotImplemented("completeTransition:")
    public void completeTransition(boolean didComplete) {}
    @NotImplemented("viewControllerForKey:")
    public UIViewController getViewController(UITransitionContextViewControllerType key) { return null; }
    @NotImplemented("viewForKey:")
    public UIView getView(UITransitionContextViewType key) { return null; }
    @NotImplemented("initialFrameForViewController:")
    public @ByVal CGRect getInitialFrame(UIViewController vc) { return null; }
    @NotImplemented("finalFrameForViewController:")
    public @ByVal CGRect getFinalFrame(UIViewController vc) { return null; }
    /*</methods>*/
}
